gt1m.accfile(file, path, fileid, counts.pos = 1,
tz = "Europe/London", sparse = FALSE,
fault = 32767)file.counts.pos = 1).strptime).classes: accfile and additional device-specific class (i.e., gt1m).
An object of class accfile is a list containing the following components:data.frame object with file identifier (fileid), accelerometer counts (counts), accelerometer steps (steps), coded error for counts (error_c) and steps (error_s). See errorCts for error codes. If sparse = TRUE, all variables except fileid of the data frame df are returned as elements of the main list with corresponding names but in sparse matrix format (see as.matrix.csr for details).data.frame object with file identifier (fileid), number of recorded measurements (nobs), epoch (epoch), accelerometer mode (mode), start date and time (ts_start), time zone (tz), battery voltage (voltage), download date and time (ts_dl).list object with file identifier (fileid), summary tables of error codes for counts (counts) and steps (steps), error code for date (date), and logical flag for odd number of measurements (odd_number) (see details).errorCts, errorSteps, and infoDate. An additional check is performed on the lenght of the sequence of measurements when both accelerometer counts and steps are recorded. If the length is odd, a warning message is produced. See file 'gt1m_sample.dat' in directory '\inst\extdata' of this package.readAccDir, gt1m.acclistdata(gt1m_sample)
class(gt1m_sample)Run the code above in your browser using DataLab