gt3x.accfile(file, path, fileid, tz = "Europe/London",
sparse = FALSE)file.strptime).classes: accfile and additional device-specific class (i.e., gt3x).
An object of class accfile is a list containing the following components:data.frame object with file identifier ('fileid'), accelerometer values in columns 'x', 'y', 'z', 'w'. If sparse = TRUE, a matrix named Data with accelerometer values is returned in sparse matrix format (see as.matrix.csr for details).data.frame object with file identifier ('fileid'), number of recorded measurements ('nobs'), epoch ('epoch'), accelerometer mode ('mode'), start date and time ('TimeStamp_orig'), time zone ('TZ'), battery voltage ('voltage'), download date and time ('TimeStamp_dl').readAccDirdata(gt3x_sample)
class(gt3x_sample)Run the code above in your browser using DataLab