This function reads a list of Actigraph GT3X accelerometer files.
gt3xAccDir(accFileList, save, compress = "gzip",
compression_level = 6, progbar = TRUE)An object of class acclist.
an object of type list.
either logical or character. See readAccDir for details.
logical or character string specifying whether saving to a named file is to use compression if save = TRUE. See argument compress in save.
integer: the level of compression to be used. See argument compression_level in save.
logical flag. Should a progress bar be used? Available for Windows only.
Marco Geraci
Actigraph (Pensacola, Florida).
readAccDir