readAccDir(path, model, ext = "dat", counts.pos = 1,
tz = "Europe/London", sparse = FALSE,
fault = 32767, save = TRUE, compress = "gzip",
compression_level = 6,...)gt1m.accfile for details.strptime).save = TRUE stores accelerometer files as .Rdata objects in a new directory ('accRfiles') in path. If the directory already exists, confirmation for overwriting will be promptsave = TRUE. See argument compress in save.compression_level in save..Rdata files or a list of objects of class accfile. In both cases, each accelerometer data file is stored as an object of type list and labelled using the data file name. See gt1m.accfile or gt3x.accfile for details.ext specifies the extension of the files to look for (e.g., 'dat' or 'txt'). Files with different extension and/or sub-directories are ignored. The data format must be consistent with the specification of model.gt1m.accfile, gt3x.accfile, gt1m.acclist, gt3x.acclist